==> jc-1.4.0.tar.gz: java/io/FilterOutputStream.h <==
// public class java.io.FilterOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_java_io_FilterOutputStream_H_
#define _JC_java_io_FilterOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_FilterOutputStream$sub_refs	_jc_java_io_FilterOutputStream$sub_refs;
typedef struct _jc_java_io_FilterOutputStream$sub_nonrefs	_jc_java_io_FilterOutputStream$sub_nonrefs;
typedef struct _jc_java_io_FilterOutputStream$refs	_jc_java_io_FilterOutputStream$refs;
typedef struct _jc_java_io_FilterOutputStream$nonrefs	_jc_java_io_FilterOutputStream$nonrefs;
typedef struct _jc_java_io_FilterOutputStream$object	_jc_java_io_FilterOutputStream$object;

typedef const struct _jc_java_io_FilterOutputStream$vmethods	_jc_java_io_FilterOutputStream$vmethods;
typedef const struct _jc_java_io_FilterOutputStream$vtable	_jc_java_io_FilterOutputStream$vtable;
typedef const struct _jc_java_io_FilterOutputStream$vtype	_jc_java_io_FilterOutputStream$vtype;

// Constructors
extern void _jc_java_io_FilterOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_java_io_FilterOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_FilterOutputStream$object *);
extern void _jc_java_io_FilterOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_FilterOutputStream$object *);
extern void _jc_java_io_FilterOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, jint);
extern void _jc_java_io_FilterOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *);
extern void _jc_java_io_FilterOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_FilterOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_FilterOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, jint);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_io_FilterOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
};

// Vtype
struct _jc_java_io_FilterOutputStream$vtype {
	_jc_type			type;
	_jc_java_io_FilterOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilterOutputStream$sub_refs {
	struct _jc_java_io_OutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_java_io_FilterOutputStream$refs {
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilterOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FilterOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
};

// Object instance structure
struct _jc_java_io_FilterOutputStream$object {
	_jc_java_io_FilterOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilterOutputStream$vtype	*vtype;
	_jc_java_io_FilterOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilterOutputStream$vtype _jc_java_io_FilterOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilterOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilterOutputStream$class_object;

#endif	/* _JC_java_io_FilterOutputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/FilterOutputStream.h <==
// public class java.io.FilterOutputStream

// class file dependencies
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_java_io_FilterOutputStream_H_
#define _JC_java_io_FilterOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_FilterOutputStream$sub_refs	_jc_java_io_FilterOutputStream$sub_refs;
typedef struct _jc_java_io_FilterOutputStream$sub_nonrefs	_jc_java_io_FilterOutputStream$sub_nonrefs;
typedef struct _jc_java_io_FilterOutputStream$refs	_jc_java_io_FilterOutputStream$refs;
typedef struct _jc_java_io_FilterOutputStream$nonrefs	_jc_java_io_FilterOutputStream$nonrefs;
typedef struct _jc_java_io_FilterOutputStream$object	_jc_java_io_FilterOutputStream$object;

typedef const struct _jc_java_io_FilterOutputStream$vmethods	_jc_java_io_FilterOutputStream$vmethods;
typedef const struct _jc_java_io_FilterOutputStream$vtable	_jc_java_io_FilterOutputStream$vtable;
typedef const struct _jc_java_io_FilterOutputStream$vtype	_jc_java_io_FilterOutputStream$vtype;

// Constructors
extern void _jc_java_io_FilterOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_FilterOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_FilterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterOutputStream$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_FilterOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_FilterOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_java_io_FilterOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_java_io_FilterOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_java_io_FilterOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_FilterOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
};

// Vtype
struct _jc_java_io_FilterOutputStream$vtype {
	_jc_type			type;
	_jc_java_io_FilterOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilterOutputStream$sub_refs {
	struct _jc_java_io_OutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_java_io_FilterOutputStream$refs {
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilterOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FilterOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
};

// Object instance structure
struct _jc_java_io_FilterOutputStream$object {
	_jc_java_io_FilterOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilterOutputStream$vtype	*vtype;
	_jc_java_io_FilterOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilterOutputStream$vtype _jc_java_io_FilterOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilterOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilterOutputStream$class_object;

#endif	/* _JC_java_io_FilterOutputStream_H_ */
